//
// Title:   SurfelList.h
// Created: Mon Sep 23 13:46:55 2002
// Authors: Matthias Zwicker
//
// Copyright (c) 2001, 2002, Computer Graphics Lab, ETH Zurich
//
// This file is part of the Pointshop3D system.
// See http://www.pointshop3d.com/ for more information.
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License as
// published by the Free Software Foundation; either version 2 of
// the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public
// License along with this program; if not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
// MA 02111-1307, USA.
//
// Contact info@pointshop3d.com if any conditions of this
// licensing are not clear to you.
//

#ifndef __SURFELLSIT_H_
#define __SURFELLIST_H_

#include "../../Interfaces/src/SurfelInterface.h"

#include <qvector.h>

/**
 * Double linked surfel list.
 * Provides a similar interface as QList.
 * @author Matthias Zwicker
 * @version 1.2
 */

// TODO: docu docu
class SurfelList {

public:

	SurfelList ();
	virtual ~SurfelList (); 

	uint count () const;
	bool isEmpty () const;

	void setAutoDeleteEnabled (const bool enable);

	void append (SurfelInterface* surfel );
	void append (const SurfelList* surfelList );

	/**
	 * CAUTION: This method fails if the <code>surfel</code> is not contained in the list!
	 */
	bool remove (SurfelInterface* surfel);
	bool remove ();
	bool removeRef (const SurfelInterface *surfel);
	bool removeFirst ();
	bool removeLast ();
	virtual void clear ();
	SurfelInterface* current () const;
	SurfelInterface* getFirst () const;
	SurfelInterface* getLast () const;
	SurfelInterface* first ();
	SurfelInterface* last ();
	SurfelInterface* next ();
	SurfelInterface* prev ();
	int find (const SurfelInterface* surfel);
	void toVector ( QVector<SurfelInterface> * vec ) const;

private:

	SurfelInterface *firstSurfel;
	SurfelInterface *lastSurfel;
	SurfelInterface *currentSurfel;
	int nSurfels;
	bool autoDelete;

};

#endif // __SURFELLIST_H_

// Some Emacs-Hints -- please don't remove:
//
//  Local Variables:
//  mode:C++
//  tab-width:4
//  End:
