//
// Title:   Surfel1.cpp
// Created: Mon Sep 23 14:02:39 2002
// Authors: Oliver Knoll, Mark Pauly, Matthias Zwicker
//
// Copyright (c) 2001, 2002, Computer Graphics Lab, ETH Zurich
//
// This file is part of the Pointshop3D system.
// See http://www.pointshop3d.com/ for more information.
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License as
// published by the Free Software Foundation; either version 2 of
// the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public
// License along with this program; if not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
// MA 02111-1307, USA.
//
// Contact info@pointshop3d.com if any conditions of this
// licensing are not clear to you.
//

#include <qdatastream.h>

#include "../../Core/Interfaces/src/SurfelInterface.h"
#include "Surfel1.h"


// **************
// static members
// **************

Surfel1 *Surfel1::_memoryStart = NULL;
uint Surfel1::SURFEL_ALLOCATION = 1024;

const MyDataTypes::TextureCoordinate Surfel1::defaultTextureCoordinate = {0.0f, 0.0f};

// TODO: update this property descriptor whenever changes are made to this class
const SurfelInterface::PropertyDescriptor Surfel1::PROPERTY_DESCRIPTOR = SurfelInterface::POSITION |
                                                                         SurfelInterface::NORMAL |
				                                                         SurfelInterface::RADIUS |
				                                                         SurfelInterface::DIFFUSE_COLOR |
															             SurfelInterface::SPECULAR_COLOR |
				                                                         SurfelInterface::FLAGS |
										                                 SurfelInterface::AMBIENT_COEFFICIENT |
										                                 SurfelInterface::DIFFUSE_COEFFICIENT |
										                                 SurfelInterface::SPECULAR_COEFFICIENT |
															             SurfelInterface::SHININESS |
															             SurfelInterface::TEXTURE_COORDINATE;

void* Surfel1::operator new (size_t) {

	Surfel1* surfel = _memoryStart;   
	if (surfel) 
		_memoryStart = _memoryStart->_memoryNext;
	else
	{
		// NOTE: the memory allocated for surfels never shrinks...
		surfel = (Surfel1 *) new char [SURFEL_ALLOCATION * sizeof(Surfel1)];
		_memoryStart = &surfel[1];	// pointer to first FREE element!
		for (uint i = 0; i < SURFEL_ALLOCATION - 2; i++) {
			_memoryStart[i]._memoryNext = &_memoryStart[i+1];
		}
		_memoryStart[SURFEL_ALLOCATION - 2]._memoryNext = NULL;
    }
	return surfel;
}

// **************
// public methods
// **************

float Surfel1::getAmbientCoefficient() const {
	return ambientCoefficient;
}

float Surfel1::getDiffuseCoefficient() const {
	return diffuseCoefficient;
}

float Surfel1::getSpecularCoefficient() const {
	return specularCoefficient;
}

float Surfel1::getShininess() const {
	return shininess;
}

MyDataTypes::TextureCoordinate Surfel1::getTextureCoordinate() const {
	return textureCoordinate;
}

SurfelInterface *Surfel1::copy() const {

	Surfel1 *deepCopy;

	deepCopy = Surfel1::create (position, normal, radius, diffuseColor, specularColor, flags,
		                        ambientCoefficient, diffuseCoefficient, specularCoefficient, shininess, textureCoordinate);
	return deepCopy;

}

// *****************
// protected methods
// *****************

Surfel1::Surfel1() {}

Surfel1::~Surfel1() {}

Surfel1* Surfel1::create (const Vector3D position, const Vector3D normal, const float radius,
				          const QRgb diffuseColor, const QRgb specularColor, const Flags flags,
				          const float ambientCoefficient, const float diffuseCoefficient, const float specularCoefficient,
				          const float shininess, const MyDataTypes::TextureCoordinate textureCoordinate) {

	Surfel1 *newSurfel = new Surfel1();

	newSurfel->position = position;
	newSurfel->normal = normal;
	newSurfel->radius = radius;
	newSurfel->diffuseColor = diffuseColor;
	newSurfel->specularColor = specularColor;
	newSurfel->flags = flags;
	newSurfel->ambientCoefficient  = ambientCoefficient;
	newSurfel->diffuseCoefficient  = diffuseCoefficient;
	newSurfel->specularCoefficient = specularCoefficient;
	newSurfel->shininess           = shininess;
	newSurfel->textureCoordinate   = textureCoordinate;

	return newSurfel;

}

void Surfel1::destroy () {
	this->_memoryNext = _memoryStart;
	_memoryStart = this;
}

void Surfel1::setAmbientCoefficient (const float newAmbientCoefficient) {
	ambientCoefficient = newAmbientCoefficient;
}

void Surfel1::setDiffuseCoefficient (const float newDiffuseCoefficient) {
	diffuseCoefficient = newDiffuseCoefficient;
}
void Surfel1::setSpecularCoefficient (const float newSpecularCoefficient) {
	specularCoefficient = newSpecularCoefficient;
}

void Surfel1::setShininess (const float newShininess) {
	shininess = newShininess;
}

void Surfel1::setTextureCoordinate (const MyDataTypes::TextureCoordinate newTextureCoordinate) {
	textureCoordinate = newTextureCoordinate;
}

void Surfel1::copy (const SurfelInterface *sourceSurfel) {
	
	// copy base attributes
	BaseSurfel::copy (sourceSurfel);

	// copy extended attributes
	ambientCoefficient  = sourceSurfel->getAmbientCoefficient();
	diffuseCoefficient  = sourceSurfel->getDiffuseCoefficient();
	specularCoefficient = sourceSurfel->getSpecularCoefficient();
	shininess           = sourceSurfel->getShininess();
	textureCoordinate   = sourceSurfel->getTextureCoordinate();

}

// Some Emacs-Hints -- please don't remove:
//
//  Local Variables:
//  mode:C++
//  tab-width:4
//  End:
