/*
 * Title:   pidefs.h
 * Created: Tue Sep 24 18:16:31 2002
 * Authors: Gilbert Baumann, Markus Noga, Tim Weyrich
 *
 * Copyright (c) 2000--2002
 * Gilbert Baumann <unk6@rz.uni-karlsruhe.de>
 * Markus Noga <markus@noga.de>
 * Tim Weyrich <weyrich@inf.ethz.ch>
 *
 * This file is part of the Pointshop3D system.
 * See http: *www.pointshop3d.com/ for more information.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later
 * version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General
 * Public License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 * Boston, MA 02111-1307 USA
 * 
 * Contact info@pointshop3d.com if any conditions of this
 * licensing are not clear to you.
 */

#ifndef __PIDEFS__
#define __PIDEFS__

#if defined(_WIN32) && !defined(WIN32)
#  define WIN32
#endif

#ifdef _WIN32
#  ifndef __STRICT_ANSI__
#    define __STRICT_ANSI__
#  endif
#endif

#if defined(__STRICT_ANSI__) && !defined(__STDC__)
#  define __STDC__ 1
#elif !defined(__STRICT_ANSI__) && defined(__STDC__)
#  define __STRICT_ANSI__ 1
#endif

#ifndef __PI_THROW
#  if defined __cplusplus && (__GNUC__ >= 3 || __GNUC_MINOR__ >= 8)
#    define __PI_THROW  throw ()
#  else
#    define __PI_THROW
#  endif
#endif

/*! \brief Indicates a function won't return.
    Applicable only to function prototypes.
 */
#if defined(_WIN32)
#  define PI_NORETURN    __declspec(noreturn)
#elif defined (GNUC)
#  define PI_NORETURN    __attribute__ ((__noreturn__))
#else
/* on SGIs (I still don't know, how to determine, whether we are on an
   SGI, so it is the else-branch :-(   ): */
#  define PI_NORETURN
#endif

/*! \brief Directive to process function inline.
 */
#if defined(_WIN32)
# define PI_INLINE      __inline
#elif defined(__GNUC__)
# define PI_INLINE      __inline__
#else
/* on SGIs (I still don't know, how to determine, whether we are on an
   SGI, so it is the else-branch :-(   ): */
# define PI_INLINE      __inline
#endif
#if defined(PROFILE) /* || defined(__STRICT_ANSI__) */
#  undef  PI_INLINE
#  define PI_INLINE  /* no inlining while profiling/in ANSI-C */
#endif

/*! \brief Struct attribute to force packing for GNU compilers.
 *
 *  Use "#pragma pack(n)" for VC++.
 */
#ifdef  __GNUC__
#  define PI_PACKED __attribute__ ((packed))
#else
#  define PI_PACKED
#endif

#define  USE(v1)                       do{(void)(v1);}while(0)
#define  USE1(v1)                      do{(void)(v1);}while(0)
#define  USE2(v1,v2)                   do{(void)(v1);(void)(v2);}while(0)
#define  USE3(v1,v2,v3)                do{(void)(v1);(void)(v2);(void)(v3);}while(0)
#define  USE4(v1,v2,v3,v4)             do{(void)(v1);(void)(v2);(void)(v3);(void)(v4);}while(0)
#define  USE5(v1,v2,v3,v4,v5)          do{USE4(v1,v2,v3,v4);USE1(v5);}while(0)
#define  USE6(v1,v2,v3,v4,v5,v6)       do{USE4(v1,v2,v3,v4);USE2(v5,v6);}while(0)
#define  USE7(v1,v2,v3,v4,v5,v6,v7)    do{USE4(v1,v2,v3,v4);USE3(v5,v6,v7);}while(0)
#define  USE8(v1,v2,v3,v4,v5,v6,v7,v8) do{USE4(v1,v2,v3,v4);USE4(v5,v6,v7,v8);}while(0)

#ifdef WIN32
/* The following ifdef block is the standard way of creating macros which make exporting
 * from a DLL simpler. All files within this DLL are compiled with the PI_EXPORTS
 * symbol defined on the command line. this symbol should not be defined on any project
 * that uses this DLL. This way any other project whose source files include this file see
 * PI_API functions as being imported from a DLL, wheras this DLL sees symbols
 * defined with this macro as being exported.
 */
#  ifdef PI_EXPORTS
#    define PI_API __declspec(dllexport)
#  else
#    define PI_API __declspec(dllimport)
#  endif
#else
#  define PI_API
#endif

#endif
