//
// Title:   CoTeXTool.cpp
// Created: Mon Mar 17 19:00:00 2003
// Authors: Clment Bichel, Blanca B. Borro Escribano, Tamy Boubekeur, Elisabeth Brunet
//
// Copyright (c) 2003, Funky CoTeX B Group, University of Bordeaux
//
// This file is part of the CoTeX plugin foir PointShop 3D
// See http://cotex.free.fr for more information.
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later
// version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Lesser General Public License for more details.
// 
// You should have received a copy of the GNU Lesser General
// Public License along with this library; if not, write to the
// Free Software Foundation, Inc., 59 Temple Place, Suite 330,
// Boston, MA 02111-1307 USA
// 
// Contact info@pointshop3d.com if any conditions of this
// licensing are not clear to you.
//

#include <qtoolbutton.h>
#include <qtoolbar.h>
#include <qcursor.h>
#include <qevent.h>
#include <qpixmap.h>
#include <qwhatsthis.h>
#include <qwidget.h>
#include <qpainter.h>
#include <qcolor.h>
#include <qlineedit.h>

#include "../../../../Core/RendererManager/src/RendererManager.h"
#include "../../../../Core/Interfaces/src/ToolInterface.h"
#include "../UI/CoTeXConfigurationWidget.h"

#include "CoTeXTool.h"

// ******************
// 'What's this' text
// ******************

static const char *whatsThisText = "<img source=\"CoTeX\"> "
"Click this button to activate the CoTeX tool"
"<ul><li>A Constructive Texturing Tool</li>"
"<li>Partition Edition</li></ul>";

// **********
// Tool class
// **********

CoTeXTool::CoTeXTool() {
	toolCursor = new QCursor (PointingHandCursor);
	cotexConfigurationWidget = new CoTeXConfigurationWidget();
}

CoTeXTool::~CoTeXTool() {
	delete toolCursor;
	delete cotexConfigurationWidget;
}

QToolButton *CoTeXTool::addButtonToToolBar (QToolBar *toolBar) {

	QIconSet iconSet;
	// create a new icon set for the button
	// path must be relative to the executable (i.e. PointShop.exe)
	// all Icons, Cursors, Bitmaps etc. which are needed by this tool should
	// go into the subdirectory 'Resources'
	QPixmap  normalIcon ("Resources/CoTeXToolIcon.png"),
		     disabledIcon ("Resources/CoTeXToolIcon_disabled.png");

	iconSet.setPixmap (normalIcon, QIconSet::Automatic, QIconSet::Normal);
	iconSet.setPixmap (disabledIcon, QIconSet::Automatic, QIconSet::Disabled);

	// add the button to the toolbar, including 'tool tip text'
	// and 'status bar text'
	toolButton = new QToolButton (iconSet, "Tool tip text", "This is the status bar text",
	                              0, 0, toolBar, "CoTeX Tool");

	// make it a toggle button
	toolButton->setToggleButton (true);

	// enable/disable it
	toolButton->setEnabled (this->checkToolAvailability());

	// add the 'What's this'-text to this button, a short description
	QWhatsThis::add (toolButton, whatsThisText);

	// make the icon visible in the 'What's this'-text, 'template' is the name of
	// the placeholder specified in the 'What's this'-text above
	QMimeSourceFactory::defaultFactory()->setPixmap ("cotex", normalIcon);

	return toolButton;

}

QToolButton *CoTeXTool::getToolButton() {
	return toolButton;
}

QCursor *CoTeXTool::getToolCursor() const {
	return toolCursor;
}

QWidget *CoTeXTool::getToolConfigurationWidget() const {
	return cotexConfigurationWidget;
}

bool CoTeXTool::isAvailable() const {
	return this->checkToolAvailability();
}

void CoTeXTool::handleKeyPressEvent (QKeyEvent *ke) {
	// it's important to ignore this event if we do not handle
	// it, so the parent widget may handle it
	ke->ignore();
}

void CoTeXTool::handleKeyReleaseEvent (QKeyEvent *ke) {
	// it's important to ignore this event if we do not handle
	// it, so the parent widget may handle it
	ke->ignore();
}

void CoTeXTool::handleMousePressEvent (QMouseEvent *me) {
}

void CoTeXTool::handleMouseReleaseEvent (QMouseEvent *) {
	// handle mouse button release events,
	// me->button() gives the button which was released
}

void CoTeXTool::handleMouseMoveEvent (QMouseEvent *) {
	// handle mouse moves events - this event is also received
	// if no mouse button is pressed. To query the mouse button
	// state, including modifiers such as Qt::ControlButton, use
	// me->state()
}

void CoTeXTool::selectTool() {
	// this tool was just seleceted by the user:
	// aquire resources if necessary
}

void CoTeXTool::deselectTool() {
	// the user selected a different tool now:
	// release resoures if necessary
}

// ************
// public slots
// ************

void CoTeXTool::handleRendererWidgetRepainted() {
	// the RenderWidget has repainted its content, so here this tool
	// can draw its content with a QPainter, if necessary
}

// ***************
// private methods
// ***************

bool CoTeXTool::checkToolAvailability() const {
	
	// TODO: check here any conditions, e.g.
	//       - if an interactive main renderer is present
	//       - if an Object is in the Scene
	//       - etc.
	return true;

}

// ****************
// access functions
// ****************

ToolInterface *createTool() {
	return new CoTeXTool();
}

const char *getToolName() {
	return "CoTeX";
}

// Some Emacs-Hints -- please don't remove:
//
//  Local Variables:
//  mode:C++
//  tab-width:4
//  End:
