//
// Title:   CoTeXTool.h
// Created: Mon Mar 17 19:00:00 2003
// Authors: Clment Bichel, Blanca B. Borro Escribano, Tamy Boubekeur, Elisabeth Brunet
//
// Copyright (c) 2003, Funky CoTeX B Group, University of Bordeaux
//
// This file is part of the CoTeX plugin foir PointShop 3D
// See http://cotex.free.fr for more information.
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later
// version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Lesser General Public License for more details.
// 
// You should have received a copy of the GNU Lesser General
// Public License along with this library; if not, write to the
// Free Software Foundation, Inc., 59 Temple Place, Suite 330,
// Boston, MA 02111-1307 USA
// 
// Contact info@pointshop3d.com if any conditions of this
// licensing are not clear to you.
//

#ifndef __COTEXTOOL_H_
#define __COTEXTOOL_H_

// **********************************************
// To compile plugins (win32):
// 
// define TOOL_EXPORTS on the command line
//
// in Visual Studio:
// Project->Settings->C/C++, Category Preprocessor
// add TOOL_EXPORTS to 'preprocessor definitions'
// ***********************************************

#include <qtoolbutton.h>
#include <qtoolbar.h>
#include <qcursor.h>
#include <qevent.h>
#include <qwidget.h>
#include <qobject.h>

#include "../../../../Core/Interfaces/src/ToolInterface.h"
#include "../UI/CoTeXConfigurationWidget.h"

/// The Constructive Texturing Tool for PointShop
/**
 * This class implements a constructive texturing tool, 
 * allowing users to partition the euclidien space in 
 * different primitives
 *
 * @author  Clment Bichel, Blanca B. Borro Escribano, Tamy Boubekeur, Elisabeth Brunet
 * @version 1.0
 */
class CoTeXTool : public ToolInterface {

	Q_OBJECT

public:
	
	TOOL_API CoTeXTool();
	TOOL_API virtual ~CoTeXTool();

	// ***********************
	// interface ToolInterface
	// ***********************

	TOOL_API QToolButton* addButtonToToolBar (QToolBar *toolBar);
	TOOL_API QToolButton *getToolButton();
	TOOL_API QCursor *getToolCursor() const;
	TOOL_API QWidget *getToolConfigurationWidget() const;
	TOOL_API bool isAvailable() const;
	
	TOOL_API void handleMousePressEvent   (QMouseEvent *me);
	TOOL_API void handleMouseReleaseEvent (QMouseEvent *me);
	TOOL_API void handleMouseMoveEvent    (QMouseEvent *me);
	TOOL_API void handleKeyPressEvent     (QKeyEvent   *ke);
	TOOL_API void handleKeyReleaseEvent   (QKeyEvent   *ke);

	TOOL_API void selectTool();
	TOOL_API void deselectTool();

public slots:

	void handleRendererWidgetRepainted();

private:

	QCursor                     *toolCursor;
	QToolButton                 *toolButton;
	CoTeXConfigurationWidget *cotexConfigurationWidget;

	bool checkToolAvailability() const;
	
};

// ****************
// access functions
// ****************

// extern "C" is needed so those functions can be accessed
// with GetProcAddress() (WIN32) and dlsym() (UNIX) respective
extern "C" {
	TOOL_API ToolInterface *createTool();
	TOOL_API const char *getToolName();
}

#endif  // __COTEXTOOL_H_

// Some Emacs-Hints -- please don't remove:
//
//  Local Variables:
//  mode:C++
//  tab-width:4
//  End:
