// ### CHECK-ME-BEFORE-RELEASE ###
//
// Title:   CameraMenu.cpp
// Created: Mon Sep 23 14:07:25 2002
// Authors: Oliver Knoll, Mark Pauly, Matthias Zwicker
//
// Copyright (c) 2001, 2002, Computer Graphics Lab, ETH Zurich
//
// This file is part of the Pointshop3D system.
// See http://www.pointshop3d.com/ for more information.
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License as
// published by the Free Software Foundation; either version 2 of
// the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public
// License along with this program; if not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
// MA 02111-1307, USA.
//
// Contact info@pointshop3d.com if any conditions of this
// licensing are not clear to you.
//

#include "../Utilities/src/Matrix.h"
#include "../Core/Scene/src/Scene.h"

#include "CameraMenu.h"

// *************
// public static
// *************

const int CameraMenu::NOF_CAMERA_POSITIONS = 10;

// **************
// public methods
// **************

CameraMenu::CameraMenu (QWidget *parent, const char *name) : QPopupMenu (parent, name) {


	// we store up to 10 camera positions
	cameraPositions.resize (NOF_CAMERA_POSITIONS);

	storeMenu   = new QPopupMenu (this);
	restoreMenu = new QPopupMenu (this);

	this->insertItem ("Store", storeMenu);
	this->insertItem ("Restore", restoreMenu);

	// add menu items
	storeMenu->insertItem ("Position 1", this, SLOT (handleStore1()), CTRL + Key_1, 10);
	storeMenu->insertItem ("Position 2", this, SLOT (handleStore2()), CTRL + Key_2, 11);
	storeMenu->insertItem ("Position 3", this, SLOT (handleStore3()), CTRL + Key_3, 12);
	storeMenu->insertItem ("Position 4", this, SLOT (handleStore4()), CTRL + Key_4, 13);
	storeMenu->insertItem ("Position 5", this, SLOT (handleStore5()), CTRL + Key_5, 14);
	storeMenu->insertItem ("Position 6", this, SLOT (handleStore6()), CTRL + Key_6, 15);
	storeMenu->insertItem ("Position 7", this, SLOT (handleStore7()), CTRL + Key_7, 16);
	storeMenu->insertItem ("Position 8", this, SLOT (handleStore8()), CTRL + Key_8, 17);
	storeMenu->insertItem ("Position 9", this, SLOT (handleStore9()), CTRL + Key_9, 18);
	storeMenu->insertItem ("Position 10", this, SLOT (handleStore10()), CTRL + Key_0, 19);
	
	restoreMenu->insertItem ("Position 1", this, SLOT (handleRestore1()), Key_1, 0);
	restoreMenu->insertItem ("Position 2", this, SLOT (handleRestore2()), Key_2, 1);
	restoreMenu->insertItem ("Position 3", this, SLOT (handleRestore3()), Key_3, 2);
	restoreMenu->insertItem ("Position 4", this, SLOT (handleRestore4()), Key_4, 3);
	restoreMenu->insertItem ("Position 5", this, SLOT (handleRestore5()), Key_5, 4);
	restoreMenu->insertItem ("Position 6", this, SLOT (handleRestore6()), Key_6, 5);
	restoreMenu->insertItem ("Position 7", this, SLOT (handleRestore7()), Key_7, 6);
	restoreMenu->insertItem ("Position 8", this, SLOT (handleRestore8()), Key_8, 7);
	restoreMenu->insertItem ("Position 9", this, SLOT (handleRestore9()), Key_9, 8);
	restoreMenu->insertItem ("Position 10", this, SLOT (handleRestore10()), Key_0, 9);

	restoreMenu->setItemEnabled (0, false);
	restoreMenu->setItemEnabled (1, false);
	restoreMenu->setItemEnabled (2, false);
	restoreMenu->setItemEnabled (3, false);
	restoreMenu->setItemEnabled (4, false);
	restoreMenu->setItemEnabled (5, false);
	restoreMenu->setItemEnabled (6, false);
	restoreMenu->setItemEnabled (7, false);
	restoreMenu->setItemEnabled (8, false);
	restoreMenu->setItemEnabled (9, false);

}

CameraMenu::~CameraMenu() {}

void CameraMenu::setCameraPosition (const MyDataTypes::CameraPosition newCameraPosition, const int index) {

	if (index >= 0 && index < NOF_CAMERA_POSITIONS) {
		cameraPositions[index] = newCameraPosition;
		restoreMenu->setItemEnabled (index, true);
	}

}

MyDataTypes::CameraPosition CameraMenu::getCameraPosition (const int index) const {

	MyDataTypes::CameraPosition undefinedPosition;

	MtrUnity4x4f (undefinedPosition.rotationMatrix);
	MtrUnity4x4f (undefinedPosition.scaleTranslationMatrix);
	if (index <= 0 && index < NOF_CAMERA_POSITIONS) {
		return cameraPositions[index];
	}
	else {
		return undefinedPosition;
	}

}

void CameraMenu::restoreCameraPosition (const int index) {
	Scene::getInstance()->setCameraPosition (cameraPositions[index]);
}

// *************
// private slots
// *************

void CameraMenu::handleStore1() {
	this->setCameraPosition (Scene::getInstance()->getCameraPosition(), 0);
}

void CameraMenu::handleStore2() {
	this->setCameraPosition (Scene::getInstance()->getCameraPosition(), 1);
}

void CameraMenu::handleStore3() {
	this->setCameraPosition (Scene::getInstance()->getCameraPosition(), 2);
}

void CameraMenu::handleStore4() {
	this->setCameraPosition (Scene::getInstance()->getCameraPosition(), 3);
}

void CameraMenu::handleStore5() {
	this->setCameraPosition (Scene::getInstance()->getCameraPosition(), 4);
}

void CameraMenu::handleStore6() {
	this->setCameraPosition (Scene::getInstance()->getCameraPosition(), 5);
}

void CameraMenu::handleStore7() {
	this->setCameraPosition (Scene::getInstance()->getCameraPosition(), 6);
}

void CameraMenu::handleStore8() {
	this->setCameraPosition (Scene::getInstance()->getCameraPosition(), 7);
}

void CameraMenu::handleStore9() {
	this->setCameraPosition (Scene::getInstance()->getCameraPosition(), 8);
}

void CameraMenu::handleStore10() {
	this->setCameraPosition (Scene::getInstance()->getCameraPosition(), 9);
}

void CameraMenu::handleRestore1() {
	this->restoreCameraPosition(0);
}

void CameraMenu::handleRestore2() {
	this->restoreCameraPosition(1);
}

void CameraMenu::handleRestore3() {
	this->restoreCameraPosition(2);
}

void CameraMenu::handleRestore4() {
	this->restoreCameraPosition(3);
}

void CameraMenu::handleRestore5() {
	this->restoreCameraPosition(4);
}

void CameraMenu::handleRestore6() {
	this->restoreCameraPosition(5);
}

void CameraMenu::handleRestore7() {
	this->restoreCameraPosition(6);
}

void CameraMenu::handleRestore8() {
	this->restoreCameraPosition(7);
}

void CameraMenu::handleRestore9() {
	this->restoreCameraPosition(8);
}

void CameraMenu::handleRestore10() {
	this->restoreCameraPosition(9);
}

// Some Emacs-Hints -- please don't remove:
//
//  Local Variables:
//  mode:C++
//  tab-width:4
//  End:
