//
// Title:   Version.h
// Created: Mon Sep 23 14:13:33 2002
// Authors: Oliver Knoll
//
// Copyright (c) 2001, 2002, Computer Graphics Lab, ETH Zurich
//
// This file is part of the Pointshop3D system.
// See http://www.pointshop3d.com/ for more information.
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License as
// published by the Free Software Foundation; either version 2 of
// the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public
// License along with this program; if not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
// MA 02111-1307, USA.
//
// Contact info@pointshop3d.com if any conditions of this
// licensing are not clear to you.
//

#ifndef __VERSION_H_
#define __VERSION_H_

#include <qdatetime.h>
#include <qstring.h>

#include "UtilitiesDLL.h"


/**
 * This namespace defines the version numbers.
 *
 * @author Oliver Knoll
 * @version 1.2
 */
namespace Version {

	/**
	 * Returns the major version number.
	 *
	 * @return the major version number
	 */
	UTILITIES_API int getMajor();

	/**
	 * Returns the major version number.
	 *
	 * @return the major version number
	 */
	UTILITIES_API int getMinor();

	/**
	 * Returns the major version number.
	 *
	 * @return the major version number
	 */
	UTILITIES_API int getSubMinor();

	/**
	 * Returns the date of this version
	 *
	 * @return the <code>QDate</code> of this version
	 */
	UTILITIES_API QDate getVersionDate();

	/**
	 * A convenience function which returns a string containing the
	 * major, minor and subminor version numbers, formated so it can
	 * readily be shown on screen.
	 *
	 * @return a <code>QString</code> containing the version number ready
	 *         to be shown on screen
	 */
	UTILITIES_API QString toString();

	/**
	 * A <code>QString</code> which contains a <em>code name</code> identifying
	 * a family of versions. Should be changed each time the major version
	 * number changes.
	 */
	UTILITIES_API QString getCodeName();

};

#endif  // __VERSION_H_

// Some Emacs-Hints -- please don't remove:
//
//  Local Variables:
//  mode:C++
//  tab-width:4
//  End:
